==> nextcloud-14.0.13.zip: nextcloud/apps/files/l10n/et_EE.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Salvestusruum pole ajutiselt kättesaadav",
    "Storage invalid" : "Vigane andmehoidla",
    "Unknown error" : "Tundmatu viga",
    "All files" : "Kõik failid",
    "Recent" : "Hiljutised",
    "Favorites" : "Lemmikud",
    "File could not be found" : "Faili ei leitud",
    "Move or copy" : "Liiguta või kopeeri",
    "Download" : "Lae alla",
    "Delete" : "Kustuta",
    "Home" : "Kodu",
    "Close" : "Sulge",
    "Could not create folder \"{dir}\"" : "Kausta \"{dir}\" loomine ebaõnnestus",
    "Upload cancelled." : "Üleslaadimine tühistati.",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ei saa üles laadida {filename}, kuna see on kataloog või selle suurus on 0 baiti",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Pole piisavalt vaba ruumi. Sa laadid üles {size1}, kuid ainult {size2} on saadaval.",
    "Target folder \"{dir}\" does not exist any more" : "Kausta \"{dir}\" pole enam olemas",
    "Not enough free space" : "Pole piisavalt vaba ruumi",
    "Uploading …" : "Üleslaadminie ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize}/{loadedSize} ({bitrate})",
    "Target folder does not exist any more" : "Sihtkataloogi pole enam olemas",
    "Error when assembling chunks, status code {status}" : "Tükkide kokkupanemise viga, staatus kood {status}",
    "Actions" : "Tegevused",
    "Rename" : "Nimeta ümber",
    "Disconnect storage" : "Ühenda andmehoidla lahti.",
    "Unshare" : "Lõpeta jagamine",
    "Could not load info for file \"{file}\"" : "Faili \"{file}\" info laadimine ebaõnnestus",
    "Files" : "Failid",
    "Details" : "Üksikasjad",
    "Select" : "Vali",
    "Pending" : "Ootel",
    "Unable to determine date" : "Kuupäeva tuvastamine ei õnnestunud",
    "This operation is forbidden" : "See toiming on keelatud",
    "This directory is unavailable, please check the logs or contact the administrator" : "See kaust pole saadaval. Palun kontrolli logifaile või võta ühendust administraatoriga",
    "Could not move \"{file}\", target exists" : "\"{file}\" liigutamine ebaõnnestus, fail on juba olemas",
    "Could not move \"{file}\"" : "\"{file}\" liigutamine ebaõnnestus",
    "Could not copy \"{file}\", target exists" : "\"{file}\" kopeerimine ebaõnnestus, sihtfail on juba olemas",
    "Could not copy \"{file}\"" : "\"{file}\" kopeerimine ebaõnnestus",
    "Copied {origin} inside {destination}" : "Kopeeris {origin} {destination} sisse",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopeeris {origin} ja {nbfiles} teist faili {destination} sisse",
    "{newName} already exists" : "{newName} on juba olemas",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" ümbernimetamine ebaõnnestus, seda pole enam olemas",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{targetName}\" on juba \"{dir}\" kaustas kasutusel. Palun valige teine nimi.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" ümbernimetamine ebaõnnestus",
    "Could not create file \"{file}\"" : "Faili \"{file}\" loomine ebaõnnestus",
    "Could not create file \"{file}\" because it already exists" : "Faili \"{file}\" loomine ebaõnnestus, sest see on juba olemas",
    "Could not create folder \"{dir}\" because it already exists" : "Kausta \"{dir}\" loomine ebaõnnestus, sest see on juba olemas",
    "Error deleting file \"{fileName}\"." : "Tõrge faili \"{fileName}\" kustutamisel.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Teistest kaustadest ei leitud {tag}{filter}{endtag}",
    "Name" : "Nimi",
    "Size" : "Suurus",
    "Modified" : "Muudetud",
    "_%n folder_::_%n folders_" : ["%n kataloog","%n kataloogi"],
    "_%n file_::_%n files_" : ["%n fail","%n faili"],
    "{dirs} and {files}" : "{dirs} ja {files}",
    "_including %n hidden_::_including %n hidden_" : ["sealhulgas %n peidetud","sealhulgas %n peidetud"],
    "You don’t have permission to upload or create files here" : "Sul puuduvad õigused siia failide üleslaadimiseks või tekitamiseks",
    "_Uploading %n file_::_Uploading %n files_" : ["Laadin üles %n faili","Laadin üles %n faili"],
    "New" : "Uus",
    "{used} of {quota} used" : "Kasutatud {used}/{quota}",
    "{used} used" : "Kasutatud {used}",
    "\"{name}\" is an invalid file name." : "\"{name}\" on vigane failinimi.",
    "File name cannot be empty." : "Faili nimi ei saa olla tühi.",
    "\"/\" is not allowed inside a file name." : "\"/\" pole failinimedes lubatud.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" pole lubatud failitüüp",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} andmemaht on täis! Faile ei uuendata ega sünkroniseerita!",
    "Your storage is full, files can not be updated or synced anymore!" : "Sinu andmemaht on täis! Faile ei uuendata ega sünkroniseerita!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Sinu {owner} andmemaht on peaaegu täis ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Su andmemaht on peaaegu täis ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["vastab '{filter}'","vastab '{filter}'"],
    "View in folder" : "Vaata kaustas",
    "Copied!" : "Kopeeritud!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopeeri otselink (töötab ainult nende kasutajate jaoks, kelle on ligipääs sellele failile/kaustale)",
    "Path" : "Asukoht",
    "_%n byte_::_%n bytes_" : ["%n bait","%n baiti"],
    "Favorited" : "Lemmikud",
    "Favorite" : "Lemmik",
    "New folder" : "Uus kaust",
    "Upload file" : "Lae fail üles",
    "Not favorited" : "Lemmikuks lisamata",
    "Remove from favorites" : "Eemalda lemmikutest",
    "Add to favorites" : "Lisa lemmikutesse",
    "An error occurred while trying to update the tags" : "Siltide uuendamisel tekkis tõrge",
    "Added to favorites" : "Lemmikutesse lisatud",
    "Removed from favorites" : "Lemmikutest eemaldatud",
    "You added {file} to your favorites" : "{file} lemmikutesse lisatud",
    "You removed {file} from your favorites" : "{file} lemmikutest eemaldatud",
    "File changes" : "Failimuudatused",
    "Created by {user}" : "Kasutaja {user} poolt loodud",
    "Changed by {user}" : "Kasutaja {user} poolt muudetud",
    "Deleted by {user}" : "Kasutaja {user} poolt kustutatud",
    "Restored by {user}" : "Kasutaja {user} poolt taastatud",
    "Renamed by {user}" : "Kasutaja {user} poolt ümber nimetatud",
    "Moved by {user}" : "Kasutaja {user} liigutatud",
    "\"remote user\"" : "\"kaugkasutaja\"",
    "You created {file}" : "Sa lõid faili {file}",
    "{user} created {file}" : "Kasutaja {user} lõi faili {file}",
    "{file} was created in a public folder" : "{file} loodi avalikku kausta",
    "You changed {file}" : "Sa muutsid faili {file}",
    "{user} changed {file}" : "Kasutaja {user} muutis faili {file}",
    "You deleted {file}" : "Sa kustutasid faili {file}",
    "{user} deleted {file}" : "Kasutaja {user} kustutas faili {file}",
    "You restored {file}" : "Sa taastasid faili {file}",
    "{user} restored {file}" : "Kasutaja {user} taastas faili {file}",
    "You renamed {oldfile} to {newfile}" : "Sa nimetasid faili ümber: {oldfile} nüüd {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} nimetas faili ümber: {oldfile} nüüd {newfile}",
    "You moved {oldfile} to {newfile}" : "Sa liigutasid faili: {oldfile} nüüd {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} liigutas faili: {oldfile} nüüd {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>Lemmikutesse</strong> on lisatud või sealt eemaldatud fail",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Fail või kaust on <strong>muudetud</strong> või <strong>ümbernimetatud</strong>",
    "A new file or folder has been <strong>created</strong>" : "Uus fail või kaust on <strong>loodud</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Fail või kaust on <strong>kustutatud</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Piira loomise ja muutuste teavitus oma <strong>lemmikfailide</strong> kohta <em>(ainult voog)</em>",
    "A file or folder has been <strong>restored</strong>" : "Fail või kaust on <strong>taastatud</strong>",
    "Unlimited" : "Piiramatult",
    "Upload (max. %s)" : "Üleslaadimine (max. %s)",
    "%s used" : "Kasutatud %s",
    "Settings" : "Seaded",
    "Show hidden files" : "Näita peidetud faile",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Kasuta seda aadressi, et <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">oma failidele WebDAV kaudu ligi pääseda</a>",
    "No files in here" : "Siin ei ole faile",
    "Upload some content or sync with your devices!" : "Laadi sisu üles või süngi oma seadmetega!",
    "No entries found in this folder" : "Selles kaustast ei leitud kirjeid",
    "Select all" : "Vali kõik",
    "Upload too large" : "Üleslaadimine on liiga suur",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Failid, mida sa proovid üles laadida, ületab serveri poolt üleslaetavatele failidele määratud maksimaalse suuruse.",
    "No favorites yet" : "Lemmikuid veel pole",
    "Files and folders you mark as favorite will show up here" : "Siin kuvatakse faile ja kaustasid, mille oled märkinud lemmikuteks",
    "Tags" : "Sildid",
    "Deleted files" : "Kustutatud failid",
    "Shared with others" : "Teistega jagatud",
    "Shared with you" : "Sinuga jagatud",
    "Shared by link" : "Jagatud lingiga",
    "Text file" : "Tekstifail",
    "New text file.txt" : "Uus tekstifail.txt",
    "Target folder" : "Sihtkaust",
    "File handling" : "Failide käsitlemine",
    "Maximum upload size" : "Maksimaalne üleslaadimise suurus",
    "max. possible: " : "maks. võimalik: ",
    "Save" : "Salvesta",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM-ga võib selle väärtuse mõju rakendamine võtta aega kuni 5 minutit pärast salvestamist.",
    "Missing permissions to edit from here." : "Puuduvad õigused siit muuta.",
    "%s of %s used" : "Kasutatud %s/%s",
    "Cancel upload" : "Tühista üleslaadimine"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.0.zip: nextcloud/apps/files/l10n/et_EE.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Salvestusruum pole ajutiselt kättesaadav",
    "Storage invalid" : "Vigane andmehoidla",
    "Unknown error" : "Tundmatu viga",
    "All files" : "Kõik failid",
    "Recent" : "Hiljutised",
    "Favorites" : "Lemmikud",
    "File could not be found" : "Faili ei leitud",
    "Move or copy" : "Liiguta või kopeeri",
    "Download" : "Lae alla",
    "Delete" : "Kustuta",
    "Home" : "Kodu",
    "Close" : "Sulge",
    "Could not create folder \"{dir}\"" : "Kausta \"{dir}\" loomine ebaõnnestus",
    "Upload cancelled." : "Üleslaadimine tühistati.",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ei saa üles laadida {filename}, kuna see on kataloog või selle suurus on 0 baiti",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Pole piisavalt vaba ruumi. Sa laadid üles {size1}, kuid ainult {size2} on saadaval.",
    "Target folder \"{dir}\" does not exist any more" : "Kausta \"{dir}\" pole enam olemas",
    "Not enough free space" : "Pole piisavalt vaba ruumi",
    "Uploading …" : "Üleslaadminie ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize}/{loadedSize} ({bitrate})",
    "Target folder does not exist any more" : "Sihtkataloogi pole enam olemas",
    "Error when assembling chunks, status code {status}" : "Tükkide kokkupanemise viga, staatus kood {status}",
    "Actions" : "Tegevused",
    "Rename" : "Nimeta ümber",
    "Disconnect storage" : "Ühenda andmehoidla lahti.",
    "Unshare" : "Lõpeta jagamine",
    "Could not load info for file \"{file}\"" : "Faili \"{file}\" info laadimine ebaõnnestus",
    "Files" : "Failid",
    "Details" : "Üksikasjad",
    "Select" : "Vali",
    "Pending" : "Ootel",
    "Unable to determine date" : "Kuupäeva tuvastamine ei õnnestunud",
    "This operation is forbidden" : "See toiming on keelatud",
    "This directory is unavailable, please check the logs or contact the administrator" : "See kaust pole saadaval. Palun kontrolli logifaile või võta ühendust administraatoriga",
    "Could not move \"{file}\", target exists" : "\"{file}\" liigutamine ebaõnnestus, fail on juba olemas",
    "Could not move \"{file}\"" : "\"{file}\" liigutamine ebaõnnestus",
    "Could not copy \"{file}\", target exists" : "\"{file}\" kopeerimine ebaõnnestus, sihtfail on juba olemas",
    "Could not copy \"{file}\"" : "\"{file}\" kopeerimine ebaõnnestus",
    "Copied {origin} inside {destination}" : "Kopeeris {origin} {destination} sisse",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopeeris {origin} ja {nbfiles} teist faili {destination} sisse",
    "{newName} already exists" : "{newName} on juba olemas",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" ümbernimetamine ebaõnnestus, seda pole enam olemas",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{targetName}\" on juba \"{dir}\" kaustas kasutusel. Palun valige teine nimi.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" ümbernimetamine ebaõnnestus",
    "Could not create file \"{file}\"" : "Faili \"{file}\" loomine ebaõnnestus",
    "Could not create file \"{file}\" because it already exists" : "Faili \"{file}\" loomine ebaõnnestus, sest see on juba olemas",
    "Could not create folder \"{dir}\" because it already exists" : "Kausta \"{dir}\" loomine ebaõnnestus, sest see on juba olemas",
    "Error deleting file \"{fileName}\"." : "Tõrge faili \"{fileName}\" kustutamisel.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Teistest kaustadest ei leitud {tag}{filter}{endtag}",
    "Name" : "Nimi",
    "Size" : "Suurus",
    "Modified" : "Muudetud",
    "_%n folder_::_%n folders_" : ["%n kataloog","%n kataloogi"],
    "_%n file_::_%n files_" : ["%n fail","%n faili"],
    "{dirs} and {files}" : "{dirs} ja {files}",
    "_including %n hidden_::_including %n hidden_" : ["sealhulgas %n peidetud","sealhulgas %n peidetud"],
    "You don’t have permission to upload or create files here" : "Sul puuduvad õigused siia failide üleslaadimiseks või tekitamiseks",
    "_Uploading %n file_::_Uploading %n files_" : ["Laadin üles %n faili","Laadin üles %n faili"],
    "New" : "Uus",
    "{used} of {quota} used" : "Kasutatud {used}/{quota}",
    "{used} used" : "Kasutatud {used}",
    "\"{name}\" is an invalid file name." : "\"{name}\" on vigane failinimi.",
    "File name cannot be empty." : "Faili nimi ei saa olla tühi.",
    "\"/\" is not allowed inside a file name." : "\"/\" pole failinimedes lubatud.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" pole lubatud failitüüp",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} andmemaht on täis! Faile ei uuendata ega sünkroniseerita!",
    "Your storage is full, files can not be updated or synced anymore!" : "Sinu andmemaht on täis! Faile ei uuendata ega sünkroniseerita!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Sinu {owner} andmemaht on peaaegu täis ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Su andmemaht on peaaegu täis ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["vastab '{filter}'","vastab '{filter}'"],
    "View in folder" : "Vaata kaustas",
    "Copied!" : "Kopeeritud!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopeeri otselink (töötab ainult nende kasutajate jaoks, kelle on ligipääs sellele failile/kaustale)",
    "Path" : "Asukoht",
    "_%n byte_::_%n bytes_" : ["%n bait","%n baiti"],
    "Favorited" : "Lemmikud",
    "Favorite" : "Lemmik",
    "New folder" : "Uus kaust",
    "Upload file" : "Lae fail üles",
    "Not favorited" : "Lemmikuks lisamata",
    "Remove from favorites" : "Eemalda lemmikutest",
    "Add to favorites" : "Lisa lemmikutesse",
    "An error occurred while trying to update the tags" : "Siltide uuendamisel tekkis tõrge",
    "Added to favorites" : "Lemmikutesse lisatud",
    "Removed from favorites" : "Lemmikutest eemaldatud",
    "You added {file} to your favorites" : "{file} lemmikutesse lisatud",
    "You removed {file} from your favorites" : "{file} lemmikutest eemaldatud",
    "File changes" : "Failimuudatused",
    "Created by {user}" : "Kasutaja {user} poolt loodud",
    "Changed by {user}" : "Kasutaja {user} poolt muudetud",
    "Deleted by {user}" : "Kasutaja {user} poolt kustutatud",
    "Restored by {user}" : "Kasutaja {user} poolt taastatud",
    "Renamed by {user}" : "Kasutaja {user} poolt ümber nimetatud",
    "Moved by {user}" : "Kasutaja {user} liigutatud",
    "\"remote user\"" : "\"kaugkasutaja\"",
    "You created {file}" : "Sa lõid faili {file}",
    "{user} created {file}" : "Kasutaja {user} lõi faili {file}",
    "{file} was created in a public folder" : "{file} loodi avalikku kausta",
    "You changed {file}" : "Sa muutsid faili {file}",
    "{user} changed {file}" : "Kasutaja {user} muutis faili {file}",
    "You deleted {file}" : "Sa kustutasid faili {file}",
    "{user} deleted {file}" : "Kasutaja {user} kustutas faili {file}",
    "You restored {file}" : "Sa taastasid faili {file}",
    "{user} restored {file}" : "Kasutaja {user} taastas faili {file}",
    "You renamed {oldfile} to {newfile}" : "Sa nimetasid faili ümber: {oldfile} nüüd {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} nimetas faili ümber: {oldfile} nüüd {newfile}",
    "You moved {oldfile} to {newfile}" : "Sa liigutasid faili: {oldfile} nüüd {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} liigutas faili: {oldfile} nüüd {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>Lemmikutesse</strong> on lisatud või sealt eemaldatud fail",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Fail või kaust on <strong>muudetud</strong> või <strong>ümbernimetatud</strong>",
    "A new file or folder has been <strong>created</strong>" : "Uus fail või kaust on <strong>loodud</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Fail või kaust on <strong>kustutatud</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Piira loomise ja muutuste teavitus oma <strong>lemmikfailide</strong> kohta <em>(ainult voog)</em>",
    "A file or folder has been <strong>restored</strong>" : "Fail või kaust on <strong>taastatud</strong>",
    "Unlimited" : "Piiramatult",
    "Upload (max. %s)" : "Üleslaadimine (max. %s)",
    "File handling" : "Failide käsitlemine",
    "Maximum upload size" : "Maksimaalne üleslaadimise suurus",
    "max. possible: " : "maks. võimalik: ",
    "Save" : "Salvesta",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "PHP-FPM-ga võib selle väärtuse mõju rakendamine võtta aega kuni 5 minutit pärast salvestamist.",
    "Missing permissions to edit from here." : "Puuduvad õigused siit muuta.",
    "%s used" : "Kasutatud %s",
    "Settings" : "Seaded",
    "Show hidden files" : "Näita peidetud faile",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Kasuta seda aadressi, et <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">oma failidele WebDAV kaudu ligi pääseda</a>",
    "Cancel upload" : "Tühista üleslaadimine",
    "No files in here" : "Siin ei ole faile",
    "Upload some content or sync with your devices!" : "Laadi sisu üles või süngi oma seadmetega!",
    "No entries found in this folder" : "Selles kaustast ei leitud kirjeid",
    "Select all" : "Vali kõik",
    "Upload too large" : "Üleslaadimine on liiga suur",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Failid, mida sa proovid üles laadida, ületab serveri poolt üleslaetavatele failidele määratud maksimaalse suuruse.",
    "No favorites yet" : "Lemmikuid veel pole",
    "Files and folders you mark as favorite will show up here" : "Siin kuvatakse faile ja kaustasid, mille oled märkinud lemmikuteks",
    "Tags" : "Sildid",
    "Deleted files" : "Kustutatud failid",
    "Shared with others" : "Teistega jagatud",
    "Shared with you" : "Sinuga jagatud",
    "Shared by link" : "Jagatud lingiga",
    "Text file" : "Tekstifail",
    "New text file.txt" : "Uus tekstifail.txt",
    "Target folder" : "Sihtkaust",
    "%s of %s used" : "Kasutatud %s/%s"
},
"nplurals=2; plural=(n != 1);");
